============================
Field Conversions Module
============================
.. currentmodule:: stravalib.field_conversions

The `field_conversions` module provides helper utility
functions to convert fields to (rich) types, e.g., `int` → `timedelta`.

Summary Functions
------------------

.. autosummary::
   :toctree: api/

   optional_input
   enum_value
   enum_values
   time_interval
   timezone
